from setuptools import setup, find_packages
setup(
    name='tkcolorlist',  # Required
    version='0.0.1',  # Required
    description='A simple list of Tk colors.',  # Required
    author='Superloach',  # Optional
    keywords='tk color list',  # Optional
    py_modules=['tkcolorlist'],  # Required
)
